@@ -1,2 +1,2 @@
 def test_command_handler_commands(command, command_handler):
-    assert command_handler.commands() == [type(command)]
+    assert command_handler.command == type(command)
